pub enum DlcError {
Show 17 variants
InvalidPublicKey(String),
MalformedLicense(String),
SignatureInvalid,
PayloadInvalid(String),
TokenCreationFailed(String),
PrivateKeyRequired,
InvalidPassphrase,
CryptoError(String),
EncryptionFailed(String),
DecryptionFailed(String),
InvalidEncryptKey(String),
InvalidNonce(String),
DlcLocked(String),
NoEncryptKey(String),
TokenProductMismatch,
DeprecatedVersion(String),
Other(String),
}Expand description
Parse a .dlcpack container and return product, embedded dlc_id, and a list
of (path, EncryptedAsset) pairs. For v3 format, also validates the signature
against the authorized product public key.
Returns: (product, dlc_id, entries, signature_bytes_if_v3)
Variants
InvalidPublicKey(String)
MalformedLicense(String)
SignatureInvalid
PayloadInvalid(String)
TokenCreationFailed(String)
PrivateKeyRequired
InvalidPassphrase
CryptoError(String)
EncryptionFailed(String)
DecryptionFailed(String)
InvalidEncryptKey(String)
InvalidNonce(String)
DlcLocked(String)
NoEncryptKey(String)
TokenProductMismatch
The DLC pack being loaded is cryptographically valid but the product it is bound to does not match the expected product. This indicates a mismatch between the pack and the game’s registered product key.
DeprecatedVersion(String)
The version of the pack being loaded is older than the minimum supported version. The string contains the minimum supported version (e.g. “3”).
Other(String)