pub struct PackItem { /* private fields */ }Expand description
Helper struct for building DLC pack entries with optional metadata.
Provides a builder pattern for creating entries to pack into a .dlcpack container.
Implementations
Sourceimpl PackItem
impl PackItem
pub fn new( path: impl Into<String>, plaintext: impl Into<Vec<u8>>, ) -> Result<Self, DlcError>
pub fn with_extension(self, ext: impl Into<String>) -> Result<Self, DlcError>
pub fn with_type_path(self, type_path: impl Into<String>) -> Self
pub fn with_type<T: Asset>(self) -> Self
Sourcepub fn path(&self) -> &str
pub fn path(&self) -> &str
Return the relative path for this item within the pack. This is used by the loader to determine how to register the decrypted asset.
Sourcepub fn plaintext(&self) -> &[u8] ⓘ
pub fn plaintext(&self) -> &[u8] ⓘ
Return the plaintext bytes for this item. This is the data that will be encrypted and stored in the pack.
pub fn ext(&self) -> Option<String>
pub fn type_path(&self) -> Option<String>