pub fn parse_encrypted(bytes: &[u8]) -> Result<EncryptedAsset, Error>Expand description
Parse the binary encrypted-asset format from a byte slice. This is used by the pack loader when parsing the pack metadata, and also by the DlcLoader when decrypting individual entries (since the entry metadata is stored in the same format as a standalone encrypted file).